@@ -3,17 +3,18 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0701';
+our $VERSION = '0.0702';
+
+use Math::Random::Discrete;
+use MIDI::Simple ();
+use List::Util qw/ min /;
 
 use Moo;
 use strictures 2;
-
-use Math::Random::Discrete;
-use MIDI::Simple;
-use List::Util qw/ min /;
-
 use namespace::clean;
 
+use constant TICKS => 96;
+
 
 has durations => (
     is      => 'ro',
@@ -163,8 +164,8 @@ sub motif {
         if (sprintf( $format, $diff ) < sprintf( $format, $self->_min_size )) {
             warn "WARNING: Leftover duration: $diff\n"
                 if $self->verbose;
-            push @$motif, 'd' . sprintf('%.0f', 96 * $diff)
-                if $self->remainder && sprintf($format, 96 * $diff) > 0;
+            push @$motif, 'd' . sprintf('%.0f', TICKS * $diff)
+                if $self->remainder && sprintf($format, TICKS * $diff) > 0;
             last;
         }
 
@@ -215,7 +216,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0701
+version 0.0702
 
 =head1 SYNOPSIS
 
@@ -242,7 +243,7 @@ version 0.0701
 
   $score->write_score('motif.mid');
 
-  # The pool may also be made of MIDI durations
+  # The pool may also be made of duration ticks
   $mdp = Music::Duration::Partition->new(
     size    => 100,
     pool    => [qw(d50 d25)],
@@ -251,7 +252,6 @@ version 0.0701
 
   # The pool may also be grouped
   $mdp = Music::Duration::Partition->new(
-    size   => 4,
     pool   => [qw(hn qn tqn)],
     groups => [0, 0, 3], # Optional
   );
